from .__version__ import __version__

name = "metalgpy"
version = __version__

from ._decorator import *
from ._expression import *
from ._sample import sample
